package cn.com.infosec.crypto.tls;

import cn.com.infosec.crypto.Digest;
import cn.com.infosec.crypto.digests.MD5Digest;
import cn.com.infosec.crypto.digests.SHA1Digest;
import cn.com.infosec.crypto.macs.HMac;
import cn.com.infosec.crypto.params.KeyParameter;
import java.io.EOFException;
import java.io.InputStream;
import java.io.OutputStream;

public class TlsUtils {
   static byte[] toByteArray(String str) {
      int var1;
      char[] str1;
      byte[] var2 = new byte[var1 = (str1 = str.toCharArray()).length];

      for(int var3 = 0; var3 != var1; ++var3) {
         var2[var3] = (byte)str1[var3];
      }

      return var2;
   }

   protected static void writeUint8(short i, OutputStream os) {
      os.write(i);
   }

   protected static void writeUint8(short i, byte[] buf, int offset) {
      buf[offset] = (byte)i;
   }

   protected static void writeUint16(int i, OutputStream os) {
      os.write(i >> 8);
      os.write(i);
   }

   protected static void writeUint16(int i, byte[] buf, int offset) {
      int var10001 = i;
      buf[offset] = (byte)(i >> 8);
      i = offset + 1;
      buf[i] = (byte)var10001;
   }

   protected static void writeUint24(int i, OutputStream os) {
      os.write(i >> 16);
      os.write(i >> 8);
      os.write(i);
   }

   protected static void writeUint24(int i, byte[] buf, int offset) {
      int var10001 = i;
      int var10003 = i;
      buf[offset] = (byte)(i >> 16);
      i = offset + 1;
      buf[i] = (byte)(var10003 >> 8);
      i = offset + 2;
      buf[i] = (byte)var10001;
   }

   protected static void writeUint32(long i, OutputStream os) {
      os.write((int)(i >> 24));
      os.write((int)(i >> 16));
      os.write((int)(i >> 8));
      os.write((int)i);
   }

   protected static void writeUint32(long i, byte[] buf, int offset) {
      byte[] var10000 = buf;
      byte[] var10002 = buf;
      byte[] var10004 = buf;
      buf[offset] = (byte)((int)(i >> 24));
      int buf1 = offset + 1;
      var10004[buf1] = (byte)((int)(i >> 16));
      buf1 = offset + 2;
      var10002[buf1] = (byte)((int)(i >> 8));
      var10000[offset + 3] = (byte)((int)i);
   }

   protected static void writeUint64(long i, OutputStream os) {
      os.write((int)(i >> 56));
      os.write((int)(i >> 48));
      os.write((int)(i >> 40));
      os.write((int)(i >> 32));
      os.write((int)(i >> 24));
      os.write((int)(i >> 16));
      os.write((int)(i >> 8));
      os.write((int)i);
   }

   protected static void writeUint64(long i, byte[] buf, int offset) {
      byte[] var10000 = buf;
      byte[] var10002 = buf;
      byte[] var10004 = buf;
      byte[] var10006 = buf;
      byte[] var10008 = buf;
      byte[] var10010 = buf;
      byte[] var10012 = buf;
      buf[offset] = (byte)((int)(i >> 56));
      int buf1 = offset + 1;
      var10012[buf1] = (byte)((int)(i >> 48));
      buf1 = offset + 2;
      var10010[buf1] = (byte)((int)(i >> 40));
      buf1 = offset + 3;
      var10008[buf1] = (byte)((int)(i >> 32));
      buf1 = offset + 4;
      var10006[buf1] = (byte)((int)(i >> 24));
      buf1 = offset + 5;
      var10004[buf1] = (byte)((int)(i >> 16));
      buf1 = offset + 6;
      var10002[buf1] = (byte)((int)(i >> 8));
      var10000[offset + 7] = (byte)((int)i);
   }

   protected static short readUint8(InputStream is) {
      int is1;
      if ((is1 = is.read()) != -1) {
         return (short)is1;
      } else {
         throw new EOFException();
      }
   }

   protected static int readUint16(InputStream is) {
      int var1;
      int is1;
      if (((var1 = is.read()) | (is1 = is.read())) >= 0) {
         return var1 << 8 | is1;
      } else {
         throw new EOFException();
      }
   }

   protected static int readUint24(InputStream is) {
      int var1;
      int var10000 = var1 = is.read();
      InputStream var10001 = is;
      int is1 = is.read();
      int var2 = var10001.read();
      if ((var10000 | is1 | var2) >= 0) {
         return var1 << 16 | is1 << 8 | var2;
      } else {
         throw new EOFException();
      }
   }

   protected static long readUint32(InputStream is) {
      int var1;
      int var10000 = var1 = is.read();
      InputStream var10001 = is;
      InputStream var10002 = is;
      int is1 = is.read();
      int var2 = var10002.read();
      int var3 = var10001.read();
      if ((var10000 | is1 | var2 | var3) >= 0) {
         return (long)var1 << 24 | (long)is1 << 16 | (long)var2 << 8 | (long)var3;
      } else {
         throw new EOFException();
      }
   }

   protected static void readFully(byte[] buf, InputStream is) {
      int var3;
      for(int var2 = 0; var2 != buf.length; var2 += var3) {
         if ((var3 = is.read(buf, var2, buf.length - var2)) == -1) {
            throw new EOFException();
         }
      }

   }

   protected static void checkVersion(byte[] readVersion, TlsProtocolHandler handler) {
      if (readVersion[0] != 3 || readVersion[1] != 1) {
         handler.failWithError((short)2, (short)70);
      }

   }

   protected static void checkVersion(InputStream is, TlsProtocolHandler handler) {
      int is1;
      if ((is1 = is.read()) != 3 || is1 != 1) {
         handler.failWithError((short)2, (short)70);
      }

   }

   protected static void writeVersion(OutputStream os) {
      os.write(3);
      os.write(1);
   }

   private static void hmac_hash(Digest digest, byte[] secret, byte[] seed, byte[] out) {
      HMac var4;
      HMac var10000 = var4 = new HMac;
      var4.<init>(digest);
      KeyParameter digest1;
      digest1 = new KeyParameter.<init>(secret);
      int secret1 = digest.getDigestSize();
      int var5 = (out.length + secret1 - 1) / secret1;
      int var6;
      byte[] var7 = new byte[var6 = var10000.getMacSize()];
      byte[] var8 = new byte[var10000.getMacSize()];
      int var9 = 0;

      for(byte[] var10 = seed; var9 < var5; var10 = var7) {
         var4.init(digest1);
         var4.update(var10, 0, var10.length);
         var4.doFinal(var7, 0);
         var4.init(digest1);
         var4.update(var7, 0, var6);
         var4.update(seed, 0, seed.length);
         var4.doFinal(var8, 0);
         int var14 = secret1 * var9;
         int var11 = Math.min(secret1, out.length - var14);
         System.arraycopy(var8, 0, out, var14, var11);
         ++var9;
      }

   }

   protected static void PRF(byte[] secret, byte[] label, byte[] seed, byte[] buf) {
      byte[] var10003 = label;
      byte[] var10004 = label;
      byte[] var10005 = label;
      byte[] var10006 = label;
      int secret1;
      int var10010 = secret1 = (secret.length + 1) / 2;
      label = new byte[var10010];
      byte[] var4 = new byte[var10010];
      System.arraycopy(secret, 0, label, 0, secret1);
      System.arraycopy(secret, secret.length - secret1, var4, 0, secret1);
      secret = new byte[var10006.length + seed.length];
      int seed1 = var10005.length;
      System.arraycopy(var10004, 0, secret, 0, seed1);
      seed1 = var10003.length;
      int var5 = seed.length;
      System.arraycopy(seed, 0, secret, seed1, var5);
      seed = new byte[buf.length];
      hmac_hash(new MD5Digest(), label, secret, seed);
      hmac_hash(new SHA1Digest(), var4, secret, buf);

      for(secret1 = 0; secret1 < buf.length; ++secret1) {
         buf[secret1] ^= seed[secret1];
      }

   }
}
